@@ -19,20 +19,19 @@ import datetime as dt
 import json
 import logging
 import math
-import msgpack
-from socket import gaierror
-import time
-from typing import Iterable, Optional, Union
-import sys
 import os
+import sys
+import time
+from socket import gaierror
+from typing import Iterable, Optional, Union
 
-from opentracing import Format
+import msgpack
+from websockets import ConnectionClosed
 
 from gs_quant.api.risk import RiskApi
 from gs_quant.risk import RiskRequest
-from gs_quant.session import GsSession
 from gs_quant.target.risk import OptimizationRequest
-from gs_quant.tracing import Tracer
+from gs_quant.tracing import Tracer, TracingSpan
 
 _logger = logging.getLogger(__name__)
 
@@ -44,6 +43,8 @@ class WebsocketUnavailable(Exception):
 class GsRiskApi(RiskApi):
     USE_MSGPACK = True
     POLL_FOR_BATCH_RESULTS = False
+    WEBSOCKET_RETRY_ON_CLOSE_CODES = (1000, 1001, 1006)
+    PRICING_API_VERSION = None
 
     @classmethod
     def calc_multi(cls, requests: Iterable[RiskRequest]) -> dict:
@@ -63,12 +64,14 @@ class GsRiskApi(RiskApi):
     def _exec(cls, request: Union[RiskRequest, Iterable[RiskRequest]]) -> Union[Iterable, dict]:
         use_msgpack = cls.USE_MSGPACK and not isinstance(request, RiskRequest)
         headers = {'Content-Type': 'application/x-msgpack'} if use_msgpack else {}
-        Tracer.inject(Format.HTTP_HEADERS, headers)
-        result, request_id = GsSession.current._post(cls.__url(request),
-                                                     request,
-                                                     request_headers=headers,
-                                                     timeout=181,
-                                                     return_request_id=True)
+        risk_session = cls.get_session()
+        version = GsRiskApi.PRICING_API_VERSION or risk_session.api_version
+        result, request_id = risk_session._post(f'/{version}' + cls.__url(request),
+                                                request,
+                                                include_version=False,
+                                                request_headers=headers,
+                                                timeout=181,
+                                                return_request_id=True)
 
         for sub_request in request:
             sub_request._id = request_id
@@ -82,7 +85,7 @@ class GsRiskApi(RiskApi):
 
     @classmethod
     async def get_results(cls, responses: asyncio.Queue, results: asyncio.Queue,
-                          timeout: Optional[int] = None) -> Optional[str]:
+                          timeout: Optional[int] = None, span: Optional[TracingSpan] = None) -> Optional[str]:
         if cls.POLL_FOR_BATCH_RESULTS:
             return await cls.__get_results_poll(responses, results, timeout=timeout)
         else:
@@ -119,7 +122,10 @@ class GsRiskApi(RiskApi):
             # ... poll for completed requests ...
 
             try:
-                calc_results = GsSession.current._post('/risk/calculate/results/bulk', list(pending_requests.keys()))
+                risk_session = cls.get_session()
+                version = GsRiskApi.PRICING_API_VERSION or risk_session.api_version
+                calc_results = risk_session._post(f'/{version}/risk/calculate/results/bulk',
+                                                  list(pending_requests.keys()), include_version=False)
 
                 # ... enqueue the request and result for the listener to handle ...
                 for result in calc_results:
@@ -136,21 +142,18 @@ class GsRiskApi(RiskApi):
     @classmethod
     async def __get_results_ws(cls, responses: asyncio.Queue, results: asyncio.Queue, timeout: Optional[int] = None):
         async def handle_websocket():
+            nonlocal all_requests_dispatched
             ret = ''
 
             try:
                 # If we're re-connecting then re-send any in-flight request ids
-
-                outstanding_request_ids = [i for i in pending_requests.keys() if i not in dispatched]
-                if outstanding_request_ids:
-                    _logger.info(f'Re-sending {len(outstanding_request_ids)} requests')
-                    await asyncio.wait_for(ws.send(json.dumps(outstanding_request_ids)), timeout=send_timeout)
-
-                all_requests_dispatched = False
+                if pending_requests:
+                    _logger.info(f'Re-subscribing {len(pending_requests)} requests')
+                    await asyncio.wait_for(ws.send(json.dumps(list(pending_requests.keys()))), timeout=send_timeout)
 
                 while pending_requests or not all_requests_dispatched:
                     # Continue while we have pending or un-dispatched requests
-
+                    _logger.debug(f'waiting for {", ".join(pending_requests.keys())}')
                     request_listener = asyncio.ensure_future(cls.drain_queue_async(responses)) \
                         if not all_requests_dispatched else None
                     result_listener = asyncio.ensure_future(ws.recv())
@@ -160,12 +163,31 @@ class GsRiskApi(RiskApi):
                     complete, pending = await asyncio.wait(listeners, return_when=asyncio.FIRST_COMPLETED)
 
                     # Check results before sending more requests. Results can be lost otherwise
-
                     if result_listener in complete:
                         # New results have been received
+                        request_id = None
                         try:
-                            request_id, status_result_str = result_listener.result().split(';', 1)
+                            raw_res = result_listener.result()
+                            parsed_res = raw_res.decode() if isinstance(raw_res, bytes) else raw_res
+                            request_id, status_result_str = parsed_res.split(';', 1)
                             status, result_str = status_result_str[0], status_result_str[1:]
+                        except ConnectionClosed as conn_closed:
+                            if conn_closed.rcvd and conn_closed.rcvd.code in cls.WEBSOCKET_RETRY_ON_CLOSE_CODES:
+                                # websocket closed, but we can retry
+                                if request_listener:
+                                    if request_listener in complete:
+                                        # WebSocket Closed on us, but had we had results just dispatched
+                                        # They need subscribing so re-queue them to pick up later
+                                        _, res = request_listener.result()
+                                        cls.enqueue(responses, res, wait=False)
+                                    else:
+                                        # Conn Closed, cancelling request listener as no-one will hear the response
+                                        # And we don't want to take anything from the queue
+                                        request_listener.cancel()
+                                # Now re-raise connection closed to be handled and potentially we'll try again
+                                raise
+                            status = 'E'
+                            result_str = str(conn_closed)
                         except Exception as ee:
                             status = 'E'
                             result_str = str(ee)
@@ -175,15 +197,23 @@ class GsRiskApi(RiskApi):
                             result = RuntimeError(result_str)
                         else:
                             # Unpack the result
-
                             try:
                                 result = msgpack.unpackb(base64.b64decode(result_str), raw=False) \
                                     if cls.USE_MSGPACK else json.loads(result_str)
                             except Exception as ee:
                                 result = ee
-
-                        # Enqueue the request and result for the listener to handle
-                        results.put_nowait((pending_requests.pop(request_id), result))
+                        if request_id is None:
+                            # Certain fatal websocket errors (e.g. ConnectionClosed) that are caught above will mean
+                            # we have no request_id - In this case we abort and set the error on all results
+                            result_listener.cancel()
+                            for req in pending_requests.values():
+                                results.put_nowait((req, result))
+                            # Give up
+                            pending_requests.clear()
+                            all_requests_dispatched = True
+                        else:
+                            # Enqueue the request and result for the listener to handle
+                            results.put_nowait((pending_requests.pop(request_id), result))
                     else:
                         result_listener.cancel()
 
@@ -193,8 +223,9 @@ class GsRiskApi(RiskApi):
 
                             all_requests_dispatched, items = request_listener.result()
                             if items:
-                                if not isinstance(items[0][1], dict):
-                                    raise RuntimeError(items[0][1][0][0][0]['errorString'])
+                                if not all([isinstance(i[1], dict) for i in items]):
+                                    error_item = next(i[1] for i in items if not isinstance(i[1], dict))
+                                    raise RuntimeError(error_item[0][0][0]['errorString'])
 
                                 # ... extract the request IDs ...
                                 request_ids = [i[1]['reportId'] for i in items]
@@ -209,6 +240,8 @@ class GsRiskApi(RiskApi):
                                 dispatched.update(request_ids)
                         else:
                             request_listener.cancel()
+            except ConnectionClosed:
+                raise
             except Exception as ee:
                 exc_type, exc_obj, exc_tb = sys.exc_info()
                 fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
@@ -216,26 +249,31 @@ class GsRiskApi(RiskApi):
 
             return ret
 
+        all_requests_dispatched = False
         pending_requests = {}
         dispatched = set()
         error = ''
+        exc_info = None
         attempts = 0
         max_attempts = 5
         send_timeout = 30
 
-        from websockets import ConnectionClosedError
         while attempts < max_attempts:
             if attempts > 0:
-                await asyncio.sleep(math.pow(2, attempts))
+                await asyncio.sleep(math.pow(2, attempts - 1))
                 _logger.error(f'{error} error, retrying (attempt {attempts + 1} of {max_attempts})')
 
             try:
-                async with GsSession.current._connect_websocket('/risk/calculate/results/subscribe') as ws:
+                risk_session = cls.get_session()
+                api_version = GsRiskApi.PRICING_API_VERSION or risk_session.api_version
+                ws_url = f'/{api_version}/risk/calculate/results/subscribe'
+                async with risk_session._connect_websocket(ws_url, include_version=False) as ws:
                     error = await handle_websocket()
 
                 attempts = max_attempts
-            except ConnectionClosedError as cce:
-                error = 'Connection failed: ' + str(cce)
+            except ConnectionClosed as cce:
+                error = (f'Unexpected Connection Closed ({len(pending_requests)}/{len(dispatched)} '
+                         f'request(s) still pending): {cce}')
                 attempts += 1
             except asyncio.TimeoutError:
                 error = 'Timed out'
@@ -244,17 +282,22 @@ class GsRiskApi(RiskApi):
                 raise WebsocketUnavailable()
             except Exception as e:
                 error = str(e)
+                exc_info = e
                 attempts = max_attempts
 
         if error != '':
-            _logger.error(f'Fatal error with websocket: {error}')
+            _logger.error(f'Fatal error with websocket: {error}', exc_info=exc_info)
+            span = Tracer.active_span()
+            if span and span.is_recording():
+                span.set_tag('error', True)
+                span.log_kv({'event': 'error', 'message': error})
             cls.shutdown_queue_listener(results)
             return error
 
     @classmethod
     def create_pretrade_execution_optimization(cls, request: OptimizationRequest) -> str:
         try:
-            response = GsSession.current._post(r'/risk/execution/pretrade', request)
+            response = cls.get_session()._post(r'/risk/execution/pretrade', request)
             _logger.info('New optimization is created with id: {}'.format(response.get("optimizationId")))
             return response
         except Exception as e:
@@ -274,7 +317,7 @@ class GsRiskApi(RiskApi):
                 time.sleep(math.pow(2, attempts))
                 _logger.error('Retrying (attempt {} of {})'.format(attempts, max_attempts))
             try:
-                results = GsSession.current._get(url)
+                results = cls.get_session()._get(url)
                 if results.get('status') == 'Running':
                     attempts += 1
                 else:
