@@ -17,13 +17,14 @@ under the License.
 import concurrent
 import socket
 from concurrent.futures.thread import ThreadPoolExecutor
-from typing import List, Callable
+from typing import List, Callable, Optional
 
 import requests
 
 from gs_quant.data import DataContext
 from gs_quant.errors import MqUninitialisedError
 from gs_quant.session import GsSession
+from gs_quant.tracing import Tracer, TracingSpan
 
 
 def handle_proxy(url, params):
@@ -57,7 +58,11 @@ class ThreadPoolManager:
 
         tasks_to_idx = {}
         for i, task in enumerate(tasks):
-            tasks_to_idx[cls.__executor.submit(cls.__run, GsSession.current, DataContext.current, task)] = i
+            tasks_to_idx[cls.__executor.submit(cls.__run,
+                                               GsSession.current,
+                                               DataContext.current,
+                                               Tracer.active_span(),
+                                               task)] = i
         results = [None] * len(tasks_to_idx)
         for task in concurrent.futures.as_completed(tasks_to_idx):
             idx = tasks_to_idx[task]
@@ -66,7 +71,7 @@ class ThreadPoolManager:
         return results
 
     @staticmethod
-    def __run(session, data_context, func):
-        with session:
+    def __run(session, data_context, span: Optional[TracingSpan], func):
+        with Tracer.activate_span(span), session:
             with data_context:
                 return func()
