@@ -153,9 +153,6 @@ class StrategySystematic:
             raise MqValueError('Cannot run backtests for different asset classes.')
         self.__use_xasset_backtesting_service = all_fx or all_ir or use_xasset_backtesting_service
 
-        if all_eq and transaction_cost_config is not None:
-            raise MqValueError('Cannot run equity backtests with transaction costs.')
-
     def __run_service_based_backtest(self, start: dt.date, end: dt.date,
                                      measures: Iterable[FlowVolBacktestMeasure]) -> BacktestResult:
         date_cfg = DateConfig(start, end)
@@ -172,7 +169,7 @@ class StrategySystematic:
         portfolio = []
         for d in sorted(set().union(basic_bt_response.portfolio.keys(), basic_bt_response.transactions.keys())):
             if d in basic_bt_response.portfolio:
-                positions = [{'instrument': i if i is not None else {}} for
+                positions = [{'instrument': i if i is not None else {}, 'quantity': self.__position_quantity(i)} for
                              i in basic_bt_response.portfolio[d]]
             else:
                 positions = []
@@ -187,6 +184,13 @@ class StrategySystematic:
             portfolio.append({'date': d, 'positions': positions, 'transactions': transactions})
         return BacktestResult(risks=risks, portfolio=portfolio)
 
+    def __position_quantity(self, instrument: dict) -> float:
+        if instrument['assetClass'] == AssetClass.Equity.value:
+            direction = 1 if instrument['buySell'] == 'Buy' else -1
+            quantity = instrument['numberOfOptions'] if instrument['type'] == 'Option' else instrument['quantity']
+            return direction * quantity
+        return None
+
     def backtest(
             self,
             start: dt.date = None,
