@@ -211,6 +211,7 @@ class ParameterField(Base):
 @dataclass(unsafe_hash=True, repr=False)
 class XAxisSettings(Base):
     auto_fit_range_to_data: Optional[bool] = field(default=None, metadata=field_metadata)
+    label: Optional[str] = field(default=None, metadata=field_metadata)
     show_grid_lines: Optional[bool] = field(default=None, metadata=field_metadata)
     ignore_nil_date: Optional[bool] = field(default=None, metadata=field_metadata)
     x_axis_date_format: Optional[str] = field(default=None, metadata=field_metadata)
@@ -225,11 +226,12 @@ class YAxisSettings(Base):
     id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
     label: Optional[str] = field(default=None, metadata=field_metadata)
     label_format: Optional[str] = field(default=None, metadata=field_metadata)
-    max_: Optional[int] = field(default=None, metadata=config(field_name='max', exclude=exclude_none))
-    min_: Optional[int] = field(default=None, metadata=config(field_name='min', exclude=exclude_none))
+    max_: Optional[float] = field(default=None, metadata=config(field_name='max', exclude=exclude_none))
+    min_: Optional[float] = field(default=None, metadata=config(field_name='min', exclude=exclude_none))
     show_grid_lines: Optional[bool] = field(default=None, metadata=field_metadata)
     hide: Optional[bool] = field(default=None, metadata=field_metadata)
     invert_axis: Optional[bool] = field(default=None, metadata=field_metadata)
+    show_label: Optional[bool] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -264,6 +266,10 @@ class ChartAnnotation(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+class ChartControls(DictBase):
+    pass
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -286,6 +292,7 @@ class ChartExpression(Base):
     line_width: Optional[float] = field(default=None, metadata=field_metadata)
     x_label: Optional[str] = field(default=None, metadata=field_metadata)
     y_label: Optional[str] = field(default=None, metadata=field_metadata)
+    default_gradient: Optional[bool] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -296,6 +303,7 @@ class ChartRegression(Base):
     type_: Optional[ChartRegressionType] = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
     line_data_index: Optional[int] = field(default=None, metadata=field_metadata)
     is_visible: Optional[bool] = field(default=None, metadata=field_metadata)
+    show_statistical_info: Optional[bool] = field(default=None, metadata=field_metadata)
     stroke_color: Optional[str] = field(default=None, metadata=field_metadata)
     stroke_type: Optional[ChartRegressionStrokeType] = field(default=None, metadata=field_metadata)
     stroke_width: Optional[float] = field(default=None, metadata=field_metadata)
@@ -338,6 +346,8 @@ class Chart(Base):
     last_updated_time: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
     entitlements: Optional[Entitlements] = field(default=None, metadata=field_metadata)
     entitlement_exclusions: Optional[EntitlementExclusions] = field(default=None, metadata=field_metadata)
+    title: Optional[str] = field(default=None, metadata=field_metadata)
+    subtitle: Optional[str] = field(default=None, metadata=field_metadata)
     rank: Optional[int] = field(default=None, metadata=field_metadata)
     folder_name: Optional[str] = field(default=None, metadata=field_metadata)
     description: Optional[str] = field(default=None, metadata=field_metadata)
@@ -347,6 +357,8 @@ class Chart(Base):
     chart_properties: Optional[Tuple[ChartProperties, ...]] = field(default=None, metadata=field_metadata)
     regression_properties: Optional[Tuple[ChartRegression, ...]] = field(default=None, metadata=field_metadata)
     real_time: Optional[bool] = field(default=None, metadata=field_metadata)
+    conversation_id: Optional[str] = field(default=None, metadata=field_metadata)
+    show_controls_toolbar: Optional[bool] = field(default=None, metadata=field_metadata)
     interval: Optional[str] = field(default=None, metadata=field_metadata)
     relative_start_date: Optional[str] = field(default=None, metadata=field_metadata)
     relative_end_date: Optional[str] = field(default=None, metadata=field_metadata)
@@ -367,3 +379,7 @@ class Chart(Base):
     y_axes_settings: Optional[Tuple[YAxisSettings, ...]] = field(default=None, metadata=field_metadata)
     annotations: Optional[Tuple[ChartAnnotation, ...]] = field(default=None, metadata=field_metadata)
     template_variables: Optional[DictBase] = field(default=None, metadata=field_metadata)
+    parameters: Optional[ChartControls] = field(default=None, metadata=field_metadata)
+    controls: Optional[Tuple[Union[ChartControls, bool, float, str], ...]] = field(default=None, metadata=field_metadata)
+    ai: Optional[str] = field(default=None, metadata=field_metadata)
+    ai_user_prompt: Optional[str] = field(default=None, metadata=field_metadata)
