@@ -77,6 +77,14 @@ class HedgerConstraintPrioritySetting(EnumBase, Enum):
     _5 = '5'    
 
 
+class SamplingPeriod(EnumBase, Enum):    
+    
+    """The length of time in between return samples."""
+
+    Daily = 'Daily'
+    Weekly = 'Weekly'    
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -87,6 +95,11 @@ class AssetConstraint(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@dataclass
+class BasketConditions(Base):
+    pass
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -296,7 +309,7 @@ class HedgerComparison(Base):
     entity_id: str = field(default=None, metadata=field_metadata)
     entity_type: HedgerComparisonType = field(default=None, metadata=field_metadata)
     hedge_properties: HedgerComparisonProperties = field(default=None, metadata=field_metadata)
-    result: Optional[DictBase] = field(default=None, metadata=field_metadata)
+    result: Optional[Union[FactorHedgeResult, PerformanceHedgeResult]] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -305,6 +318,8 @@ class HedgerComparison(Base):
 @dataclass(unsafe_hash=True, repr=False)
 class Target(Base):
     id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
+    tags: Optional[Tuple[PositionTag, ...]] = field(default=None, metadata=field_metadata)
+    parent_sts_id: Optional[str] = field(default=None, metadata=field_metadata)
     positions: Optional[Tuple[Position, ...]] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
@@ -331,6 +346,7 @@ class FactorHedgeParameters(Base):
     explode_universe: Optional[bool] = field(default=None, metadata=field_metadata)
     min_names: Optional[float] = field(default=None, metadata=field_metadata)
     max_names: Optional[float] = field(default=None, metadata=field_metadata)
+    max_trades: Optional[float] = field(default=None, metadata=field_metadata)
     min_weight: Optional[float] = field(default=None, metadata=field_metadata)
     max_weight: Optional[float] = field(default=None, metadata=field_metadata)
     min_market_cap: Optional[float] = field(default=None, metadata=field_metadata)
@@ -341,13 +357,20 @@ class FactorHedgeParameters(Base):
     asset_constraints: Optional[Tuple[AssetConstraint, ...]] = field(default=None, metadata=field_metadata)
     constrain_assets_by_notional: Optional[bool] = field(default=None, metadata=field_metadata)
     allow_long_short: Optional[bool] = field(default=None, metadata=field_metadata)
+    only_reweight_target_composition: Optional[bool] = field(default=None, metadata=field_metadata)
     factor_constraints: Optional[Tuple[FactorConstraint, ...]] = field(default=None, metadata=field_metadata)
     classification_constraints: Optional[Tuple[ClassificationConstraint, ...]] = field(default=None, metadata=field_metadata)
     esg_constraints: Optional[Tuple[ESGConstraint, ...]] = field(default=None, metadata=field_metadata)
     constraint_priority_settings: Optional[FactorHedgerConstraintPrioritySettings] = field(default=None, metadata=field_metadata)
     comparisons: Optional[Tuple[HedgerComparison, ...]] = field(default=None, metadata=field_metadata)
     turnover_portfolio_id: Optional[str] = field(default=None, metadata=field_metadata)
+    turnover_tags: Optional[Tuple[PositionTag, ...]] = field(default=None, metadata=field_metadata)
     max_turnover_percentage: Optional[float] = field(default=None, metadata=field_metadata)
+    turnover_notional_type: Optional[str] = field(default=None, metadata=field_metadata)
+    return_type: Optional[ReturnType] = field(default=None, metadata=field_metadata)
+    is_best_basket: Optional[bool] = field(default=None, metadata=field_metadata)
+    is_sector_etf: Optional[bool] = field(default=None, metadata=config(field_name='isSectorETF', exclude=exclude_none))
+    is_sts: Optional[bool] = field(default=None, metadata=config(field_name='isSTS', exclude=exclude_none))
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -362,7 +385,7 @@ class PerformanceHedgeParameters(Base):
     observation_end_date: datetime.date = field(default=None, metadata=field_metadata)
     backtest_start_date: Optional[datetime.date] = field(default=None, metadata=field_metadata)
     backtest_end_date: Optional[datetime.date] = field(default=None, metadata=field_metadata)
-    sampling_period: Optional[str] = field(default='Weekly', metadata=field_metadata)
+    sampling_period: Optional[SamplingPeriod] = field(default=SamplingPeriod.Weekly, metadata=field_metadata)
     max_leverage: Optional[float] = field(default=None, metadata=field_metadata)
     percentage_in_cash: Optional[float] = field(default=None, metadata=field_metadata)
     explode_universe: Optional[bool] = field(default=None, metadata=field_metadata)
@@ -374,6 +397,7 @@ class PerformanceHedgeParameters(Base):
     max_adv_percentage: Optional[float] = field(default=None, metadata=field_metadata)
     max_return_deviation: Optional[float] = field(default=None, metadata=field_metadata)
     max_weight: Optional[float] = field(default=None, metadata=field_metadata)
+    min_weight: Optional[float] = field(default=None, metadata=field_metadata)
     min_market_cap: Optional[float] = field(default=None, metadata=field_metadata)
     max_market_cap: Optional[float] = field(default=None, metadata=field_metadata)
     market_participation_rate: Optional[float] = field(default=10, metadata=field_metadata)
@@ -384,6 +408,8 @@ class PerformanceHedgeParameters(Base):
     use_machine_learning: Optional[bool] = field(default=False, metadata=field_metadata)
     lasso_weight: Optional[float] = field(default=None, metadata=field_metadata)
     ridge_weight: Optional[float] = field(default=None, metadata=field_metadata)
+    return_type: Optional[ReturnType] = field(default=None, metadata=field_metadata)
+    is_sts: Optional[bool] = field(default=None, metadata=config(field_name='isSTS', exclude=exclude_none))
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -392,7 +418,7 @@ class PerformanceHedgeParameters(Base):
 @dataclass(unsafe_hash=True, repr=False)
 class Hedge(Base):
     name: str = field(default=None, metadata=field_metadata)
-    parameters: DictBase = field(default=None, metadata=field_metadata)
+    parameters: Union[FactorHedgeParameters, PerformanceHedgeParameters] = field(default=None, metadata=field_metadata)
     id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
     owner_id: Optional[str] = field(default=None, metadata=field_metadata)
     created_by_id: Optional[str] = field(default=None, metadata=field_metadata)
@@ -403,5 +429,5 @@ class Hedge(Base):
     tags: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     description: Optional[str] = field(default=None, metadata=field_metadata)
     objective: Optional[HedgeObjective] = field(default=None, metadata=field_metadata)
-    result: Optional[DictBase] = field(default=None, metadata=field_metadata)
+    result: Optional[Union[FactorHedgeResult, PerformanceHedgeResult]] = field(default=None, metadata=field_metadata)
     comparison_results: Optional[Tuple[HedgerComparison, ...]] = field(default=None, metadata=field_metadata)
