@@ -17,7 +17,7 @@ under the License.
 import datetime as dt
 
 from gs_quant.api.gs.risk_models import GsRiskModelApi, GsFactorRiskModelApi
-from gs_quant.session import *
+from gs_quant.session import Environment, GsSession
 from gs_quant.target.risk_models import RiskModel, Factor, RiskModelCalendar, \
     RiskModelDataAssetsRequest as DataAssetsRequest, RiskModelDataMeasure as Measure, \
     RiskModelUniverseIdentifierRequest as UniverseIdentifier
