@@ -119,6 +119,23 @@ factor_data = [
     }
 ]
 
+aum_data = {
+    '2020-01-01': 1,
+    '2020-01-02': 2,
+    '2020-01-03': 1,
+    '2020-01-04': 1,
+    '2020-01-05': 1,
+    '2020-01-06': 3
+}
+
+yield_data = {
+    pd.Timestamp('2020-01-01'): .01,
+    pd.Timestamp('2020-01-02'): .02,
+    pd.Timestamp('2020-01-03'): .025,
+    pd.Timestamp('2020-01-04'): .03,
+    pd.Timestamp('2020-01-05'): .04,
+}
+
 thematic_data = [
     {
         "date": "2021-07-12",
@@ -503,25 +520,33 @@ def test_hit_rate():
     replace = Replacer()
     data = {
         'pnl': [
-            101,
+            .2,
             0,
-            1
+            1,
+            -.97
         ],
         'date': [
             '2020-01-01',
             '2020-01-01',
+            '2020-01-02',
             '2020-01-02'
         ],
         'entryType': [
+            'Holding',
             'Holding',
             'Holding',
             'Holding'
+        ],
+        'assetId': [
+            'asset1',
+            'asset2',
+            'asset1',
+            'asset2'
         ]
     }
 
     timeseries = {
-        '2020-01-01': .5,
-        '2020-01-02': 1
+        '2020-01-02': .5
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
@@ -533,7 +558,7 @@ def test_hit_rate():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_hit_rate("test")
+        returned = mp.portfolio_hit_rate("test", 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -568,46 +593,8 @@ def test_max_drawdown():
     replace.restore()
 
 
-def test_drawdown_length():
-    replace = Replacer()
-    data = {
-        '2020-01-01': 1,
-        '2020-01-02': 2,
-        '2020-01-03': 1,
-        '2020-01-04': 0
-    }
-
-    timeseries = {
-        pd.Timestamp('2020-01-01 00:00:00'): np.nan,
-        pd.Timestamp('2020-01-02 00:00:00'): np.nan,
-        pd.Timestamp('2020-01-03 00:00:00'): np.nan,
-        pd.Timestamp('2020-01-04 00:00:00'): 2
-    }
-
-    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
-    mock.return_value = data
-    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
-    mock.return_value = PerformanceReport()
-    mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
-    mock.return_value = PerformanceReport()
-
-    max_drawdown_series = pd.Series(timeseries)
-    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 4)):
-        returned = mp.portfolio_drawdown_length("test", 4)
-        assert max_drawdown_series.equals(returned)
-    replace.restore()
-
-
 def test_max_recovery_period():
     replace = Replacer()
-    data = {
-        '2020-01-01': 1,
-        '2020-01-02': 2,
-        '2020-01-03': 1,
-        '2020-01-04': 1,
-        '2020-01-05': 1,
-        '2020-01-06': 3
-    }
 
     timeseries = {
         pd.Timestamp('2020-01-01 00:00:00'): np.nan,
@@ -619,7 +606,7 @@ def test_max_recovery_period():
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
-    mock.return_value = data
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
     mock.return_value = PerformanceReport()
     mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
@@ -632,6 +619,32 @@ def test_max_recovery_period():
     replace.restore()
 
 
+def test_drawdown_length():
+    replace = Replacer()
+
+    timeseries = {
+        pd.Timestamp('2020-01-01 00:00:00'): np.nan,
+        pd.Timestamp('2020-01-02 00:00:00'): np.nan,
+        pd.Timestamp('2020-01-03 00:00:00'): np.nan,
+        pd.Timestamp('2020-01-04 00:00:00'): np.nan,
+        pd.Timestamp('2020-01-05 00:00:00'): np.nan,
+        pd.Timestamp('2020-01-06 00:00:00'): 3
+    }
+
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport()
+    mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
+    mock.return_value = PerformanceReport()
+
+    max_drawdown_series = pd.Series(timeseries)
+    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 6)):
+        returned = mp.portfolio_drawdown_length("test", 6)
+        assert max_drawdown_series.equals(returned)
+    replace.restore()
+
+
 def test_standard_deviation():
     replace = Replacer()
     data = {
@@ -650,8 +663,10 @@ def test_standard_deviation():
     timeseries = {
         '2020-01-01': np.nan,
         '2020-01-02': np.nan,
-        '2020-01-03': 1
+        '2020-01-03': 1.41421
     }
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -661,7 +676,7 @@ def test_standard_deviation():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_standard_deviation("test", '3d')
+        returned = mp.portfolio_standard_deviation("test", '2d')
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -684,9 +699,10 @@ def test_downside_risk():
     timeseries = {
         '2020-01-01': np.nan,
         '2020-01-02': np.nan,
-        '2020-01-03': 8
+        '2020-01-03': 5
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -696,7 +712,7 @@ def test_downside_risk():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_downside_risk("test", 3)
+        returned = mp.portfolio_downside_risk("test", 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -720,10 +736,11 @@ def test_semi_variance():
 
     timeseries = {
         '2020-01-01': np.nan,
-        '2020-01-02': 8,
-        '2020-01-03': 9
+        '2020-01-02': np.nan,
+        '2020-01-04': 8
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -757,9 +774,10 @@ def test_kurtosis():
     timeseries = {
         '2020-01-01': np.nan,
         '2020-01-02': np.nan,
-        '2020-01-03': -1.5
+        '2020-01-03': -2
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -769,7 +787,7 @@ def test_kurtosis():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_kurtosis("test", 3)
+        returned = mp.portfolio_kurtosis("test", 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -793,9 +811,10 @@ def test_skewness():
     timeseries = {
         '2020-01-01': np.nan,
         '2020-01-02': np.nan,
-        '2020-01-03': .93522
+        '2020-01-03': 0
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -805,7 +824,7 @@ def test_skewness():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_skewness("test", 3)
+        returned = mp.portfolio_skewness("test", 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -829,9 +848,10 @@ def test_realized_var():
     timeseries = {
         '2020-01-01': np.nan,
         '2020-01-02': np.nan,
-        '2020-01-03': -1
+        '2020-01-03': -0.52500
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -841,7 +861,7 @@ def test_realized_var():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_realized_var("test", 3)
+        returned = mp.portfolio_realized_var("test", 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -861,7 +881,8 @@ def test_bad_date():
             '2020-01-03'
         ]
     }
-
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
     mock.return_value = pd.DataFrame(data)
     mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
@@ -912,16 +933,9 @@ def test_tracking_error():
     timeseries = {
         pd.Timestamp('2020-01-01'): np.nan,
         pd.Timestamp('2020-01-02'): np.nan,
-        pd.Timestamp('2020-01-03'): np.nan,
-        pd.Timestamp('2020-01-04'): 0.016893,
-        pd.Timestamp('2020-01-05'): 0.838388
-    }
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': 1.035,
-        '2020-01-03': 1.05,
-        '2020-01-04': 1.06,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-03'): 0.00340,
+        pd.Timestamp('2020-01-04'): 0.003603,
+        pd.Timestamp('2020-01-05'): 0.010537
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -943,8 +957,8 @@ def test_tracking_error():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_tracking_error("test", 'test', 3)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        returned = mp.portfolio_tracking_error("test", 'test', 2)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -979,16 +993,9 @@ def test_tracking_error_bull():
     timeseries = {
         pd.Timestamp('2020-01-01'): np.nan,
         pd.Timestamp('2020-01-02'): np.nan,
-        pd.Timestamp('2020-01-03'): np.nan,
-        pd.Timestamp('2020-01-04'): 0.016893,
-        pd.Timestamp('2020-01-05'): 0.838388
-    }
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': 1.035,
-        '2020-01-03': 1.05,
-        '2020-01-04': 1.06,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-03'): 0.71771,
+        pd.Timestamp('2020-01-04'): 0.70357,
+        pd.Timestamp('2020-01-05'): 0.34648
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1010,7 +1017,7 @@ def test_tracking_error_bull():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_tracking_error_bull("test", 'test', 3)
+        returned = mp.portfolio_tracking_error_bull("test", 'test', 2)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -1048,13 +1055,6 @@ def test_tracking_error_bear():
         pd.Timestamp('2020-01-02'): np.nan,
         pd.Timestamp('2020-01-03'): np.nan,
     }
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': 1.035,
-        '2020-01-03': 1.05,
-        '2020-01-04': 1.06,
-        '2020-01-05': 1.065
-    }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
     mock.return_value = aum_data
@@ -1075,8 +1075,8 @@ def test_tracking_error_bear():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_tracking_error_bear("test", 'test', 3)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        returned = mp.portfolio_tracking_error_bear("test", 'test', 2)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1111,9 +1111,9 @@ def test_sharpe_ratio():
     timeseries = {
         pd.Timestamp('2020-01-01'): np.nan,
         pd.Timestamp('2020-01-02'): np.nan,
-        pd.Timestamp('2020-01-03'): 0.47194,
-        pd.Timestamp('2020-01-04'): 0.46717,
-        pd.Timestamp('2020-01-05'): 1.18668,
+        pd.Timestamp('2020-01-03'): np.nan,
+        pd.Timestamp('2020-01-04'): 32.60231,
+        pd.Timestamp('2020-01-05'): 33.77863,
     }
     aum_data = {
         '2020-01-01': 1.00,
@@ -1142,8 +1142,8 @@ def test_sharpe_ratio():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_sharpe_ratio("test", 'test')
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        returned = mp.portfolio_sharpe_ratio("test", 'test', 2)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1176,8 +1176,8 @@ def test_calmar_ratio():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-04 00:00:00'): -1.40006,
-        pd.Timestamp('2020-01-05 00:00:00'): -5.31133
+        pd.Timestamp('2020-01-04 00:00:00'): 16.20658,
+        pd.Timestamp('2020-01-05 00:00:00'): 30.31192
     }
 
     aum_data = {
@@ -1208,7 +1208,7 @@ def test_calmar_ratio():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_calmar_ratio("test", 3)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1218,7 +1218,7 @@ def test_sortino_ratio():
         'pnl': [
             .02,
             .02,
-            .01,
+            -.01,
             .02,
             .01
 
@@ -1235,13 +1235,14 @@ def test_sortino_ratio():
     yield_data = {
         pd.Timestamp('2020-01-01'): .001,
         pd.Timestamp('2020-01-02'): .07,
-        pd.Timestamp('2020-01-03'): .07,
-        pd.Timestamp('2020-01-04'): .001,
+        pd.Timestamp('2020-01-03'): .08,
+        pd.Timestamp('2020-01-04'): .075,
         pd.Timestamp('2020-01-05'): .02
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-05 00:00:00'): 0.238755
+        pd.Timestamp('2020-01-04 00:00:00'): 15.063383,
+        pd.Timestamp('2020-01-05 00:00:00'): 10.128712,
     }
 
     aum_data = {
@@ -1271,7 +1272,7 @@ def test_sortino_ratio():
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_sortino_ratio("test", "test", 4)
+        returned = mp.portfolio_sortino_ratio("test", "test", 3)
         assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
     replace.restore()
 
@@ -1282,7 +1283,7 @@ def test_sortino_ratio_index():
         'pnl': [
             .02,
             .02,
-            .01,
+            -.01,
             .02,
             .01
 
@@ -1305,7 +1306,7 @@ def test_sortino_ratio_index():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-05 00:00:00'): -1.357158
+        pd.Timestamp('2020-01-05 00:00:00'): -8.355985
     }
 
     aum_data = {
@@ -1336,7 +1337,7 @@ def test_sortino_ratio_index():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2020, 1, 2)):
         returned = mp.portfolio_sortino_ratio("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1369,16 +1370,8 @@ def test_jensen_alpha():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-04 00:00:00'): 0.091926,
-        pd.Timestamp('2020-01-05 00:00:00'): -4.31556
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-04 00:00:00'): 0.01814,
+        pd.Timestamp('2020-01-05 00:00:00'): 0.00661
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1401,7 +1394,7 @@ def test_jensen_alpha():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_jensen_alpha("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1443,15 +1436,7 @@ def test_jensen_bull():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-04 00:00:00'): -0.88850
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-04 00:00:00'): 0.02530
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1474,7 +1459,7 @@ def test_jensen_bull():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_jensen_alpha_bull("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1492,10 +1477,10 @@ def test_jensen_alpha_bear():
     data = {
         'pnl': [
             .02,
-            .02,
-            .01,
-            .02,
-            .01
+            -.02,
+            -.01,
+            -.02,
+            -.01
 
         ],
         'date': [
@@ -1519,14 +1504,6 @@ def test_jensen_alpha_bear():
         pd.Timestamp('2020-01-04 00:00:00'): -0.88850
     }
 
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
-    }
-
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
     mock.return_value = aum_data
 
@@ -1548,7 +1525,7 @@ def test_jensen_alpha_bear():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_jensen_alpha_bear("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1585,17 +1562,9 @@ def test_information_ratio():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-02 00:00:00'): 0.72226,
-        pd.Timestamp('2020-01-03 00:00:00'): -0.52595,
-        pd.Timestamp('2020-01-04 00:00:00'): -1.72708
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-02 00:00:00'): 0.748532,
+        pd.Timestamp('2020-01-03 00:00:00'): -1.583948,
+        pd.Timestamp('2020-01-04 00:00:00'): -1.065513
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1618,7 +1587,7 @@ def test_information_ratio():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_information_ratio("test", "test")
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1655,17 +1624,10 @@ def test_information_ratio_bull():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-03 00:00:00'): -0.875757,
-        pd.Timestamp('2020-01-04 00:00:00'): -2.875757
+        pd.Timestamp('2020-01-03 00:00:00'): -6.11050,
+        pd.Timestamp('2020-01-04 00:00:00'): -4.11050
     }
 
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
-    }
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
     mock.return_value = aum_data
     mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
@@ -1686,7 +1648,7 @@ def test_information_ratio_bull():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_information_ratio_bull("test", "test")
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1723,16 +1685,8 @@ def test_information_ratio_bear():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-02 00:00:00'): 2.10443,
-        pd.Timestamp('2020-01-03 00:00:00'): 4.10443
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065
+        pd.Timestamp('2020-01-02 00:00:00'): 20.36364,
+        pd.Timestamp('2020-01-03 00:00:00'): 22.36364
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1755,7 +1709,7 @@ def test_information_ratio_bear():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_information_ratio_bear("test", "test")
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1775,8 +1729,8 @@ def test_modigliani_ratio():
         'pnl': [
             .02,
             .02,
-            .01,
-            .002,
+            -.01,
+            -.002,
             .003,
             .01,
             .002,
@@ -1804,19 +1758,8 @@ def test_modigliani_ratio():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-05 00:00:00'): 7.29426,
-        pd.Timestamp('2020-01-06 00:00:00'): 9.76735,
-        pd.Timestamp('2020-01-07 00:00:00'): 10.45107
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+        pd.Timestamp('2020-01-05 00:00:00'): 0.31288,
+        pd.Timestamp('2020-01-06 00:00:00'): 0.20278
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1831,6 +1774,9 @@ def test_modigliani_ratio():
     mock = replace('gs_quant.entities.entity.Entity.get_data_coordinate', Mock())
     mock.return_value = DataCoordinate("test")
     mock = replace('gs_quant.data.coordinate.DataCoordinate.get_series', Mock(side_effect=[pd.Series(benchmark_data),
+                                                                                           pd.Series(yield_data),
+                                                                                           pd.Series(yield_data),
+                                                                                           pd.Series(yield_data),
                                                                                            pd.Series(yield_data)]))
     mock.return_value = pd.Series(benchmark_data)
 
@@ -1840,7 +1786,7 @@ def test_modigliani_ratio():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_modigliani_ratio("test", "test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1879,20 +1825,14 @@ def test_treynor_measure():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-04 00:00:00'): 0.67779,
-        pd.Timestamp('2020-01-05 00:00:00'): 1.84438,
-        pd.Timestamp('2020-01-06 00:00:00'): 2.47558,
-        pd.Timestamp('2020-01-07 00:00:00'): 0.74686
+        pd.Timestamp('2020-01-04 00:00:00'): -0.01426,
     }
 
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+    benchmark_data = {
+        pd.Timestamp('2020-01-01'): 6,
+        pd.Timestamp('2020-01-02'): 5,
+        pd.Timestamp('2020-01-03'): 4,
+        pd.Timestamp('2020-01-04'): 9
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -1907,15 +1847,16 @@ def test_treynor_measure():
     mock.return_value = Bond("test", 'test', )
     mock = replace('gs_quant.entities.entity.Entity.get_data_coordinate', Mock())
     mock.return_value = DataCoordinate("test")
-    replace('gs_quant.data.coordinate.DataCoordinate.get_series', Mock(side_effect=[pd.Series(yield_data)]))
+    replace('gs_quant.data.coordinate.DataCoordinate.get_series',
+            Mock(side_effect=[pd.Series(benchmark_data), pd.Series(yield_data)]))
 
     mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
     mock.return_value = PerformanceReport()
 
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
-        returned = mp.portfolio_treynor_measure("test", 'test')
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        returned = mp.portfolio_treynor_measure("test", 'test', 'test')
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -1964,9 +1905,9 @@ def test_alpha():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-05 00:00:00'): 7.74826,
-        pd.Timestamp('2020-01-06 00:00:00'): -11.20258,
-        pd.Timestamp('2020-01-07 00:00:00'): -20.46613
+        pd.Timestamp('2020-01-05 00:00:00'): -1.61319,
+        pd.Timestamp('2020-01-06 00:00:00'): -3.73679,
+        pd.Timestamp('2020-01-07 00:00:00'): -1.38878
     }
 
     aum_data = {
@@ -2048,18 +1989,9 @@ def test_beta():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-06 00:00:00'): 0.082328,
-        pd.Timestamp('2020-01-07 00:00:00'): 0.149586
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+        pd.Timestamp('2020-01-05 00:00:00'): 0.00118,
+        pd.Timestamp('2020-01-06 00:00:00'): 0.00070,
+        pd.Timestamp('2020-01-07 00:00:00'): 0.00106
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -2082,7 +2014,7 @@ def test_beta():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_beta("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -2131,18 +2063,8 @@ def test_correlation():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-06 00:00:00'): 0.37506,
-        pd.Timestamp('2020-01-07 00:00:00'): 0.92789
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+        pd.Timestamp('2020-01-06 00:00:00'): 0.21846,
+        pd.Timestamp('2020-01-07 00:00:00'): 0.40573
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -2165,7 +2087,7 @@ def test_correlation():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_correlation("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -2214,18 +2136,8 @@ def test_r_squared():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-06 00:00:00'): 0.140667,
-        pd.Timestamp('2020-01-07 00:00:00'): 0.860985
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+        pd.Timestamp('2020-01-05 00:00:00'): 0.04772,
+        pd.Timestamp('2020-01-06 00:00:00'): 0.16462
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
@@ -2248,7 +2160,7 @@ def test_r_squared():
     expected = pd.Series(timeseries)
     with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 2)):
         returned = mp.portfolio_r_squared("test", "test", 4)
-        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-6)
+        assert np.allclose(expected.dropna(), returned.dropna(), atol=1e-5)
     replace.restore()
 
 
@@ -2297,19 +2209,8 @@ def test_capture_ratio():
     }
 
     timeseries = {
-        pd.Timestamp('2020-01-05 00:00:00'): 0.63053,
-        pd.Timestamp('2020-01-06 00:00:00'): 0.66166,
-        pd.Timestamp('2020-01-07 00:00:00'): 0.73877
-    }
-
-    aum_data = {
-        '2020-01-01': 1.00,
-        '2020-01-02': .95,
-        '2020-01-03': .9,
-        '2020-01-04': 1.03,
-        '2020-01-05': 1.065,
-        '2020-01-06': 1.08,
-        '2020-01-07': 1.072
+        pd.Timestamp('2020-01-05 00:00:00'): 0.50900,
+        pd.Timestamp('2020-01-06 00:00:00'): 0.69110
     }
 
     mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
