@@ -13,21 +13,26 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-
+import datetime as dt
+import numpy as np
+import pandas as pd
 import pytest
 from pandas.testing import assert_series_equal
 
-from gs_quant.timeseries import *
+from gs_quant.errors import MqValueError
+from gs_quant.timeseries import moving_average, Window, smoothed_moving_average, macd, bollinger_bands, \
+    relative_strength_index, exponential_moving_average, exponential_volatility, exponential_spread_volatility, trend, \
+    SeasonalModel, Frequency, seasonally_adjusted
 
 
 def test_moving_average():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 5),
-        date(2019, 1, 6),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 5),
+        dt.date(2019, 1, 6),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -51,12 +56,12 @@ def test_moving_average():
 
 def test_smoothed_moving_average():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 5),
-        date(2019, 1, 6),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 5),
+        dt.date(2019, 1, 6),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -84,12 +89,12 @@ def test_smoothed_moving_average():
 
 def test_macd():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 5),
-        date(2019, 1, 6),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 5),
+        dt.date(2019, 1, 6),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -103,12 +108,12 @@ def test_macd():
 
 def test_bollinger_bands():
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 5),
-        date(2019, 1, 6),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 5),
+        dt.date(2019, 1, 6),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -129,28 +134,28 @@ def test_bollinger_bands():
 
 
 def test_relative_strength_index():
-    dates = [datetime.date(2020, 1, 2),
-             datetime.date(2020, 1, 3),
-             datetime.date(2020, 1, 6),
-             datetime.date(2020, 1, 7),
-             datetime.date(2020, 1, 8),
-             datetime.date(2020, 1, 9),
-             datetime.date(2020, 1, 10),
-             datetime.date(2020, 1, 13),
-             datetime.date(2020, 1, 14),
-             datetime.date(2020, 1, 15),
-             datetime.date(2020, 1, 16),
-             datetime.date(2020, 1, 17),
-             datetime.date(2020, 1, 21),
-             datetime.date(2020, 1, 22),
-             datetime.date(2020, 1, 23),
-             datetime.date(2020, 1, 24),
-             datetime.date(2020, 1, 27),
-             datetime.date(2020, 1, 28),
-             datetime.date(2020, 1, 29),
-             datetime.date(2020, 1, 30),
-             datetime.date(2020, 1, 31),
-             datetime.date(2020, 2, 3)]
+    dates = [dt.date(2020, 1, 2),
+             dt.date(2020, 1, 3),
+             dt.date(2020, 1, 6),
+             dt.date(2020, 1, 7),
+             dt.date(2020, 1, 8),
+             dt.date(2020, 1, 9),
+             dt.date(2020, 1, 10),
+             dt.date(2020, 1, 13),
+             dt.date(2020, 1, 14),
+             dt.date(2020, 1, 15),
+             dt.date(2020, 1, 16),
+             dt.date(2020, 1, 17),
+             dt.date(2020, 1, 21),
+             dt.date(2020, 1, 22),
+             dt.date(2020, 1, 23),
+             dt.date(2020, 1, 24),
+             dt.date(2020, 1, 27),
+             dt.date(2020, 1, 28),
+             dt.date(2020, 1, 29),
+             dt.date(2020, 1, 30),
+             dt.date(2020, 1, 31),
+             dt.date(2020, 2, 3)]
 
     SPX_values = [3257.8501,
                   3234.8501,
@@ -193,28 +198,26 @@ def test_relative_strength_index():
     expected = pd.Series(data=np.ones(7) * 100, index=dates[15:])
     result = relative_strength_index(increasing_series, w)
     assert_series_equal(result, expected, check_names=False, obj="Relative Strength Index")
-
     result = relative_strength_index(SPX, "2w")
     print(result)
 
 
 def test_exponential_moving_average():
-
     def ema_by_hand(ts, alpha=0.75):
         R = ts.copy()
         R *= 0
-        R[0] = ts[0]
+        R.iloc[0] = ts.iloc[0]
         for i in range(1, len(ts)):
-            R[i] = alpha * R[i - 1] + (1 - alpha) * ts[i]
+            R.iloc[i] = alpha * R.iloc[i - 1] + (1 - alpha) * ts.iloc[i]
         return R
 
     dates = [
-        date(2019, 1, 1),
-        date(2019, 1, 2),
-        date(2019, 1, 3),
-        date(2019, 1, 4),
-        date(2019, 1, 5),
-        date(2019, 1, 6),
+        dt.date(2019, 1, 1),
+        dt.date(2019, 1, 2),
+        dt.date(2019, 1, 3),
+        dt.date(2019, 1, 4),
+        dt.date(2019, 1, 5),
+        dt.date(2019, 1, 6),
     ]
 
     x = pd.Series([3.0, 2.0, 3.0, 1.0, 3.0, 6.0], index=dates)
@@ -257,14 +260,14 @@ def test_trend():
     long_x = pd.Series(range(len(long_dates)), index=long_dates)
     res = trend(long_x)  # Should not be all NaN, make sure it's correct length
     assert len(res) == len(long_x)
-    assert np.isclose(res[int(len(res) / 2)], long_x[int(len(res) / 2)], 0.1)
-    assert res.notnull().any()
+    assert np.isclose(res.iloc[int(len(res) / 2)], long_x.iloc[int(len(res) / 2)], 0.1)
+    assert res.notna().any()
     with pytest.raises(ValueError):
         trend(long_x, SeasonalModel.MULTIPLICATIVE)  # Should not be all NaN, make sure it's correct length
     res = trend(long_x + 1, SeasonalModel.MULTIPLICATIVE)  # Should not be all NaN, make sure it's correct length
     assert len(res) == len(long_x)
-    assert np.isclose((res[int(len(res) / 2)] - 1), long_x[int(len(res) / 2)], 0.1)
-    assert res.notnull().any()
+    assert np.isclose((res.iloc[int(len(res) / 2)] - 1), long_x.iloc[int(len(res) / 2)], 0.1)
+    assert res.notna().any()
     with pytest.raises(MqValueError):
         x = pd.Series(range(10))
         trend(x)
@@ -272,7 +275,7 @@ def test_trend():
 
 def test_seasonality_adjusted():
     # Test that correctly runs with different frequencies
-    for pfreq in ['B', 'D', 'W', 'M', 'Q', 'Y']:
+    for pfreq in ['B', 'D', 'W', 'ME', 'QE', 'YE']:
         for freq in [Frequency.YEAR, Frequency.QUARTER, Frequency.MONTH, Frequency.WEEK]:
             dates = pd.date_range('2019-01-01', '2021-01-05', freq=pfreq)
             series = pd.Series(range(len(dates)), index=dates) + 1
