@@ -14,18 +14,24 @@
 # Chart Service will attempt to make public functions (not prefixed with _) from this module available. Such functions
 # should be fully documented: docstrings should describe parameters and the return value, and provide a 1-line
 # description. Type annotations should be provided for parameters.
-from .analysis import LagMode, lag
-from .statistics import *
-from ..errors import *
+import math
+from enum import IntEnum, Enum
 from typing import Union
+
 import numpy as np
 import pandas as pd
-from gs_quant.api.gs.data import GsDataApi
-from gs_quant.data import DataContext
-from gs_quant.datetime.date import DayCountConvention
+
+from gs_quant.api.gs.data import GsDataApi, QueryType
+from gs_quant.common import Currency
 from gs_quant.markets.securities import Asset
-from gs_quant.target.common import Currency
-from gs_quant.timeseries.datetime import align
+from .analysis import LagMode, lag
+from .datetime import align, interpolate
+from .helper import CurveType, Interpolate, Window, normalize_window, apply_ramp, plot_session_function, \
+    plot_function, Returns, SeriesType
+from .statistics import std, product, sum_
+from ..data import DataContext
+from ..datetime import DayCountConvention, day_count_fraction
+from ..errors import MqValueError, MqTypeError
 
 """
 Econometrics timeseries library is for standard economic and time series analytics operations, including returns,
@@ -106,7 +112,7 @@ def _annualized_return(levels: pd.Series, rolling: Union[int, pd.DateOffset],
         starting = [0] * rolling
         starting.extend([a for a in range(1, len(levels) - rolling + 1)])
         points = list(
-            map(lambda d, v, i: pow(v / levels[i], 365.25 / (d - levels.index[i]).days) - 1, levels.index[1:],
+            map(lambda d, v, i: pow(v / levels.iloc[i], 365.25 / (d - levels.index[i]).days) - 1, levels.index[1:],
                 levels.values[1:], starting[1:]))
     points.insert(0, 0)
     return pd.Series(points, index=levels.index)
@@ -446,7 +452,7 @@ def _get_annualization_factor(x):
         distances.append(d)
         prev_idx = idx
 
-    average_distance = numpy.average(distances)
+    average_distance = np.average(distances)
     if average_distance < 2.1:
         factor = AnnualizationFactor.DAILY
     elif 6 <= average_distance < 8:
@@ -477,7 +483,7 @@ def annualize(x: pd.Series) -> pd.Series:
     Based on number of days between observations, will determine an annualization factor and then adjust values
     accordingly. Useful for annualizing daily or monthly returns
 
-    :math:`Y_t = X_t * \sqrt{F}`
+    :math:`Y_t = X_t * \\sqrt{F}`
 
     Annualization factors as follows, based on period implied by observations:
 
@@ -545,9 +551,9 @@ def volatility(x: pd.Series, w: Union[Window, int, str] = Window(None, 0),
                   where :math:`X_t` is the asset price at time :math:`t`
     ===========   =======================================================
 
-    and :math:`\overline{R_t}` is the mean value over the same window:
+    and :math:`\\overline{R_t}` is the mean value over the same window:
 
-    :math:`\overline{R_t} = \\frac{\sum_{i=t-w+1}^{t} R_t}{N}`
+    :math:`\\overline{R_t} = \\frac{\\sum_{i=t-w+1}^{t} R_t}{N}`
 
     If window is not provided, computes realized volatility over the full series
 
@@ -574,7 +580,8 @@ def volatility(x: pd.Series, w: Union[Window, int, str] = Window(None, 0),
 
 @plot_function
 def correlation(x: pd.Series, y: pd.Series,
-                w: Union[Window, int, str] = Window(None, 0), type_: SeriesType = SeriesType.PRICES) -> pd.Series:
+                w: Union[Window, int, str] = Window(None, 0), type_: SeriesType = SeriesType.PRICES,
+                returns_type: Returns = Returns.SIMPLE) -> pd.Series:
     """
     Rolling correlation of two price series
 
@@ -584,6 +591,8 @@ def correlation(x: pd.Series, y: pd.Series,
               and 10 the ramp up value. If w is a string, it should be a relative date like '1m', '1d', etc.
               Window size defaults to length of series.
     :param type_: type of both input series: prices or returns
+    :param returns_type: Method to calculate returns when type_ is PRICES, simple, logarithmic or absolute. You can
+                        also pass two methods to calculate returns for x and y respectively.
     :return: date-based time series of correlation
 
     **Usage**
@@ -591,12 +600,13 @@ def correlation(x: pd.Series, y: pd.Series,
     Calculate rolling `realized correlation <https://en.wikipedia.org/wiki/Correlation_and_dependence>`_,
     :math:`\\rho_t` of two price series over a given window:
 
-    :math:`\\rho_t = \\frac{\sum_{i=t-w+1}^t (R_t - \overline{R_t})(Y_t - \overline{S_t})}{(N-1)\sigma R_t\sigma S_t}`
+    :math:`\\rho_t =
+    \\frac{\\sum_{i=t-w+1}^t (R_t - \\overline{R_t})(Y_t - \\overline{S_t})}{(N-1)\\sigma R_t\\sigma S_t}`
 
     where N is the number of observations in each rolling window, :math:`w`, and :math:`R_t` and :math:`S_t` are the
     simple returns for each series on time :math:`t`
 
-    If prices are provided:
+    If prices are provided then returns are calculated based on the returns_type e.g. for simple returns:
 
     :math:`R_t = \\frac{X_t}{X_{t-1}} - 1` and :math:`S_t = \\frac{Y_t}{Y_{t-1}} - 1`
 
@@ -604,8 +614,8 @@ def correlation(x: pd.Series, y: pd.Series,
 
     :math:`R_t = X_t` and :math:`S_t = Y_t`
 
-    :math:`\overline{R_t}`, :math:`\overline{S_t}` are the mean values, and :math:`\sigma R_{t}` and
-    :math:`\sigma S_{t}` are the sample standard deviations, of  series
+    :math:`\\overline{R_t}`, :math:`\\overline{S_t}` are the mean values, and :math:`\\sigma R_{t}` and
+    :math:`\\sigma S_{t}` are the sample standard deviations, of  series
     :math:`R_t` and :math:`S_t` over the same window
 
     If window is not provided, computes realized correlation over the full series
@@ -629,15 +639,32 @@ def correlation(x: pd.Series, y: pd.Series,
         return x
 
     given_prices = type_ == SeriesType.PRICES
-    ret_1 = returns(x) if given_prices else x
-    ret_2 = returns(y) if given_prices else y
+    if given_prices:
+        if isinstance(returns_type, (tuple, list)):
+            if len(returns_type) != 2:
+                raise MqValueError('Expected a list of length 2 for "returns_type"')
+            if not all(isinstance(r, Returns) for r in returns_type):
+                raise MqTypeError('Expected a list of Returns for "returns_type"')
+            returns_type_x, returns_type_y = returns_type
+        else:
+            returns_type_x = returns_type_y = returns_type
+        ret_1 = returns(x, type=returns_type_x)
+        ret_2 = returns(y, type=returns_type_y)
+    else:
+        ret_1 = x
+        ret_2 = y
 
     clean_ret1 = ret_1.dropna()
     clean_ret2 = ret_2.dropna()
 
     if isinstance(w.w, pd.DateOffset):
-        values = [clean_ret1.loc[(clean_ret1.index > idx - w.w) & (clean_ret1.index <= idx)].corr(clean_ret2)
-                  for idx in clean_ret1.index]
+        if isinstance(clean_ret1.index, pd.DatetimeIndex):
+            values = [clean_ret1.loc[(clean_ret1.index > idx - w.w) & (clean_ret1.index <= idx)].corr(clean_ret2)
+                      for idx in clean_ret1.index]
+        else:
+            values = [clean_ret1.loc[(clean_ret1.index > (idx - w.w).date()) &
+                                     (clean_ret1.index <= idx)].corr(clean_ret2)
+                      for idx in clean_ret1.index]
         corr = pd.Series(values, index=clean_ret1.index)
     else:
         corr = clean_ret1.rolling(w.w, 0).corr(clean_ret2)
@@ -718,7 +745,7 @@ def beta(x: pd.Series, b: pd.Series, w: Union[Window, int, str] = Window(None, 0
         offset = w.w
         start = 0
         for i in range(1, size):
-            min_index_value = series_index[i] - offset
+            min_index_value = (series_index[i] - offset).date()
             for idx in range(start, i + 1):
                 if series_index[idx] > min_index_value:
                     start = idx
@@ -743,7 +770,7 @@ def max_drawdown(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) ->
     """
     Compute the maximum peak to trough drawdown over a rolling window as a ratio.
 
-    i.e. if the max drawdown for a period is 20%, this function will return 0.2.
+    i.e. if the max drawdown for a period is 20%, this function will return -0.2.
 
     :param x: time series
     :param w: Window, int, or str: size of window and ramp up to use. e.g. Window(22, 10) where 22 is the window size
@@ -765,10 +792,13 @@ def max_drawdown(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) ->
     """
     w = normalize_window(x, w)
     if isinstance(w.w, pd.DateOffset):
-        scores = pd.Series([x[idx] / x.loc[(x.index > idx - w.w) & (x.index <= idx)].max() - 1 for idx in x.index],
-                           index=x.index)
-        result = pd.Series([scores.loc[(scores.index > idx - w.w) & (scores.index <= idx)].min()
-                            for idx in scores.index], index=scores.index)
+        if pd.api.types.is_datetime64_dtype(x.index):
+            scores = pd.Series([x[idx] / x.loc[(x.index > (idx - w.w)) & (x.index <= idx)].max() - 1
+                                for idx in x.index], index=x.index)
+            result = pd.Series([scores.loc[(scores.index > (idx - w.w)) & (scores.index <= idx)].min()
+                                for idx in scores.index], index=scores.index)
+        else:
+            raise TypeError('Please pass in list of dates as index')
     else:
         rolling_max = x.rolling(w.w, 0).max()
         result = (x / rolling_max - 1).rolling(w.w, 0).min()
