@@ -15,24 +15,21 @@ under the License.
 """
 import logging
 from enum import Enum
+from numbers import Real
 from typing import Union, Optional
 
 import pandas as pd
-from numbers import Real
-from pandas import Series
 
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.data import QueryType, GsDataApi
+from gs_quant.common import AssetClass, AssetType, PricingLocation
 from gs_quant.errors import MqValueError
 from gs_quant.markets.securities import AssetIdentifier, Asset, SecurityMaster
-from gs_quant.target.common import AssetClass, AssetType, PricingLocation
 from gs_quant.timeseries import ASSET_SPEC, plot_measure, MeasureDependency
 from gs_quant.timeseries import ExtendedSeries, measures_rates as tm_rates
-from gs_quant.timeseries import measures as tm
 from gs_quant.timeseries.measures import _asset_from_spec, _market_data_timed, _cross_stored_direction_helper, \
     _preprocess_implied_vol_strikes_fx, _tenor_month_to_year
 from gs_quant.timeseries.measures_helper import VolReference
-from gs_quant.data.log import log_debug
 
 _logger = logging.getLogger(__name__)
 
@@ -289,8 +286,17 @@ CURRENCY_TO_DUMMY_FFO_BBID_VOL_SWAPS = {
 }
 
 
-def _currencypair_to_tdapi_fxfwd_asset(_asset_spec: ASSET_SPEC) -> str:
-    return "MA8RY265Q34P7TWZ"
+def _currencypair_to_tdapi_fxfwd_asset(asset_spec: ASSET_SPEC) -> str:
+    asset = _asset_from_spec(asset_spec)
+    bbid = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
+
+    kwargs = dict(asset_class='FX', type='Forward',
+                  asset_parameters_pair=bbid,
+                  asset_parameters_settlement_date='1y',
+                  )
+
+    mqid = _get_tdapi_fxo_assets(**kwargs)
+    return mqid
 
 
 def _currencypair_to_tdapi_fxo_asset(asset_spec: ASSET_SPEC) -> str:
@@ -323,6 +329,47 @@ def _get_tdapi_fxo_assets(**kwargs) -> Union[str, list]:
         return assets[0].id
 
 
+def get_fxo_asset(asset: Asset, expiry_tenor: str, strike: str, option_type: str = None,
+                  expiration_location: str = None, premium_payment_date: str = None) -> str:
+    cross = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
+
+    if cross not in FX_DEFAULTS.keys():
+        raise NotImplementedError('Data not available for {} FX Vanilla options'.format(cross))
+
+    defaults = _get_fxo_defaults(cross)
+
+    if not (tm_rates._is_valid_relative_date_tenor(expiry_tenor)):
+        raise MqValueError('invalid expiry ' + expiry_tenor)
+
+    if expiration_location is None:
+        _ = defaults["expirationTime"]
+    else:
+        _ = expiration_location
+
+    if premium_payment_date is None:
+        premium_date = defaults["premiumPaymentDate"]
+    else:
+        premium_date = premium_payment_date
+
+    if option_type == "Put":
+        call_ccy = defaults["over"]
+        put_ccy = defaults["under"]
+    else:
+        call_ccy = defaults["under"]
+        put_ccy = defaults["over"]
+
+    kwargs = dict(asset_class='FX', type='Option',
+                  asset_parameters_call_currency=call_ccy,
+                  asset_parameters_put_currency=put_ccy,
+                  asset_parameters_expiration_date=expiry_tenor,
+                  asset_parameters_option_type=option_type,
+                  asset_parameters_premium_payment_date=premium_date,
+                  asset_parameters_strike_price_relative=strike,
+                  )
+
+    return _get_tdapi_fxo_assets(**kwargs)
+
+
 def _get_tdapi_fxo_assets_vol_swaps(**kwargs) -> Union[str, list]:
     # sanitize input for asset query.
 
@@ -376,7 +423,7 @@ def _get_fx_vol_swap_data(asset: Asset, expiry_tenor: str, strike_type: str = No
                           query_type: QueryType = QueryType.STRIKE_VOL) \
         -> pd.DataFrame:
     if real_time:
-        raise NotImplementedError('realtime inflation swap data not implemented')
+        raise NotImplementedError('realtime FX Vol swap data not implemented')
 
     cross = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
 
@@ -410,7 +457,13 @@ def _get_fxfwd_data(asset: Asset, settlement_date: str,
                     query_type: QueryType = QueryType.FWD_POINTS) \
         -> pd.DataFrame:
     if real_time:
-        raise NotImplementedError('realtime inflation swap data not implemented')
+        mqid = asset.get_identifier(AssetIdentifier.MARQUEE_ID)
+        q = GsDataApi.build_market_data_query([mqid], QueryType.FORWARD_POINT, source=source,
+                                              real_time=real_time, where={'tenor': settlement_date})
+        _logger.debug('q %s', q)
+        df = _market_data_timed(q)
+        return df
+
     cross = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
 
     if not (tm_rates._is_valid_relative_date_tenor(settlement_date)):
@@ -421,7 +474,7 @@ def _get_fxfwd_data(asset: Asset, settlement_date: str,
                   asset_parameters_settlement_date=settlement_date,
                   )
 
-    rate_mqid = _get_tdapi_fxo_assets(**kwargs)
+    mqid = _get_tdapi_fxo_assets(**kwargs)
 
     if location is None:
         pricing_location = PricingLocation.NYC
@@ -430,7 +483,7 @@ def _get_fxfwd_data(asset: Asset, settlement_date: str,
 
     where = dict(pricingLocation=pricing_location.value)
 
-    q = GsDataApi.build_market_data_query([rate_mqid], query_type, where=where, source=source,
+    q = GsDataApi.build_market_data_query([mqid], query_type, where=where, source=source,
                                           real_time=real_time)
     _logger.debug('q %s', q)
     df = _market_data_timed(q)
@@ -444,44 +497,10 @@ def _get_fxo_data(asset: Asset, expiry_tenor: str, strike: str, option_type: str
                   query_type: QueryType = QueryType.IMPLIED_VOLATILITY) \
         -> pd.DataFrame:
     if real_time:
-        raise NotImplementedError('realtime inflation swap data not implemented')
-    cross = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
+        raise NotImplementedError('realtime FX Option data not implemented')
 
-    if cross not in FX_DEFAULTS.keys():
-        raise NotImplementedError('Data not available for {} FX Vanilla options'.format(cross))
-
-    defaults = _get_fxo_defaults(cross)
-
-    if not (tm_rates._is_valid_relative_date_tenor(expiry_tenor)):
-        raise MqValueError('invalid expiry ' + expiry_tenor)
-
-    if expiration_location is None:
-        _ = defaults["expirationTime"]
-    else:
-        _ = expiration_location
-
-    if premium_payment_date is None:
-        premium_date = defaults["premiumPaymentDate"]
-    else:
-        premium_date = premium_payment_date
-
-    if option_type == "Put":
-        call_ccy = defaults["over"]
-        put_ccy = defaults["under"]
-    else:
-        call_ccy = defaults["under"]
-        put_ccy = defaults["over"]
-
-    kwargs = dict(asset_class='FX', type='Option',
-                  asset_parameters_call_currency=call_ccy,
-                  asset_parameters_put_currency=put_ccy,
-                  asset_parameters_expiration_date=expiry_tenor,
-                  asset_parameters_option_type=option_type,
-                  asset_parameters_premium_payment_date=premium_date,
-                  asset_parameters_strike_price_relative=strike,
-                  )
-
-    asset_mqid = _get_tdapi_fxo_assets(**kwargs)
+    asset_mqid = get_fxo_asset(asset=asset, expiry_tenor=expiry_tenor, strike=strike, option_type=option_type,
+                               expiration_location=expiration_location, premium_payment_date=premium_payment_date)
 
     if location is None:
         pricing_location = PricingLocation.NYC
@@ -503,7 +522,7 @@ def _get_fxo_data(asset: Asset, expiry_tenor: str, strike: str, option_type: str
 def implied_volatility_new(asset: Asset, expiry_tenor: str, strike: str, option_type: str = None,
                            expiration_location: str = None,
                            location: PricingLocation = None, premium_payment_date: str = None, *,
-                           source: str = None, real_time: bool = False) -> Series:
+                           source: str = None, real_time: bool = False) -> pd.Series:
     """
     GS end-of-day FX vanilla implied volatilities across major crosses.
 
@@ -531,82 +550,44 @@ def implied_volatility_new(asset: Asset, expiry_tenor: str, strike: str, option_
     return series
 
 
-"""
-Legacy implementation
-"""
-
-
-def legacy_implied_volatility(asset: Asset, tenor: str, strike_reference: VolReference = None,
-                              relative_strike: Real = None, *, source: str = None, real_time: bool = False,
-                              request_id: Optional[str] = None) -> Series:
-    """
-    Volatility of an asset implied by observations of market prices.
-
-    :param asset: asset object loaded from security master
-    :param tenor: relative date representation of expiration date e.g. 1m
-            or absolute calendar strips e.g. 'Cal20', 'F20-G20'
-    :param strike_reference: reference for strike level
-    :param relative_strike: strike relative to reference
-    :param source: name of function caller
-    :param real_time: whether to retrieve intraday data instead of EOD
-    :param request_id: service request id, if any
-    :return: implied volatility curve
-    """
-
-    asset_id = tm.cross_stored_direction_for_fx_vol(asset.get_marquee_id())
-    ref_string, relative_strike = tm._preprocess_implied_vol_strikes_fx(strike_reference, relative_strike)
-
-    log_debug(request_id, _logger, 'where tenor=%s, strikeReference=%s, relativeStrike=%s', tenor, ref_string,
-              relative_strike)
-    tenor = tm._tenor_month_to_year(tenor)
-    where = dict(tenor=tenor, strikeReference=ref_string, relativeStrike=relative_strike)
-    # Parallel calls when fetching / appending last results
-    df = tm.get_historical_and_last_for_measure([asset_id], QueryType.IMPLIED_VOLATILITY, where, source=source,
-                                                real_time=real_time, request_id=request_id)
-
-    s = tm._extract_series_from_df(df, QueryType.IMPLIED_VOLATILITY)
-    return s
-
-
 """
 New Implementation
 """
 
 
-@plot_measure((AssetClass.FX,), None,
+@plot_measure((AssetClass.FX,), (AssetType.Cross,),
               [MeasureDependency(id_provider=cross_stored_direction_for_fx_vol,
                                  query_type=QueryType.IMPLIED_VOLATILITY)],
               display_name="implied_volatility")
 def implied_volatility_fxvol(asset: Asset, tenor: str, strike_reference: VolReference = None,
                              relative_strike: Real = None, location: Optional[PricingLocation] = None,
                              legacy_implementation: bool = False, *,
-                             source: str = None, real_time: bool = False,
-                             request_id: Optional[str] = None) -> Series:
+                             source: str = None, real_time: bool = False) -> pd.Series:
     """
     Volatility of an asset implied by observations of market prices.
 
     :param asset: asset object loaded from security master
     :param tenor: relative date representation of expiration date e.g. 1m
             or absolute calendar strips e.g. 'Cal20', 'F20-G20'
-    :param strike_reference: reference for strike level
+    :param strike_reference: reference for strike level. Forward is used for ATMF. Default market convention
+            for FX implied vols is delta neutral
     :param relative_strike: strike relative to reference
     :param location: location of the data snapshot Example - "HKG", "LDN", "NYC"
-    :param legacy_implementation: use FX_IVOl over  FX_VANILLA_OPTIONS_VOLS
+    :param legacy_implementation: Deprecated (supplied values are ignored)
     :param source: name of function caller
     :param real_time: whether to retrieve intraday data instead of EOD
-    :param request_id: service request id, if any
     :return: implied volatility curve
     """
 
-    if legacy_implementation:
-        return (legacy_implied_volatility(asset, tenor, strike_reference, relative_strike,
-                                          source=source, real_time=real_time, request_id=request_id))
-
     bbid = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
     if bbid is not None:
         cross = _cross_stored_direction_helper(bbid)
         if cross != bbid:
             cross_asset = SecurityMaster.get_asset(cross, AssetIdentifier.BLOOMBERG_ID)
+            if strike_reference.value == VolReference.DELTA_CALL.value:
+                strike_reference = VolReference.DELTA_PUT
+            elif strike_reference.value == VolReference.DELTA_PUT.value:
+                strike_reference = VolReference.DELTA_CALL
         else:
             cross_asset = asset
     else:
@@ -645,9 +626,9 @@ def implied_volatility_fxvol(asset: Asset, tenor: str, strike_reference: VolRefe
                                  query_type=QueryType.FWD_POINTS)],
               display_name="forward_point")
 def fwd_points(asset: Asset, settlement_date: str,
-               location: str = None, *, source: str = None, real_time: bool = False) -> Series:
+               location: str = None, *, source: str = None, real_time: bool = False) -> pd.Series:
     """
-    GS end-of-day FX vanilla implied volatilities across major crosses.
+    GS End-of-day FX forward points for G3, G10, and EM crosses.
 
     :param asset: asset object loaded from security master
     :param settlement_date: relative date representation of expiration date e.g. 1m
@@ -659,8 +640,10 @@ def fwd_points(asset: Asset, settlement_date: str,
     df = _get_fxfwd_data(asset=asset, settlement_date=settlement_date,
                          location=location, source=source,
                          real_time=real_time, query_type=QueryType.FWD_POINTS)
-
-    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['fwdPoints'])
+    if real_time:
+        series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['forwardPoint'])
+    else:
+        series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['fwdPoints'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -670,7 +653,7 @@ def fwd_points(asset: Asset, settlement_date: str,
                                  query_type=QueryType.STRIKE_VOL)])
 def vol_swap_strike(asset: Asset, expiry_tenor: str, strike_type: str = None,
                     location: PricingLocation = None, *,
-                    source: str = None, real_time: bool = False) -> Series:
+                    source: str = None, real_time: bool = False) -> pd.Series:
     """
     GS end-of-day FX Vol Swaps volatilities across major crosses.
 
